@@ -1,28 +1,20 @@
 use strict;
 use warnings;
-package Plack::App::BeanstalkConsole;
-{
-  $Plack::App::BeanstalkConsole::VERSION = '0.007';
-}
-# git description: v0.006-2-g45485a2
-
-BEGIN {
-  $Plack::App::BeanstalkConsole::AUTHORITY = 'cpan:ETHER';
-}
+package Plack::App::BeanstalkConsole; # git description: v0.007-12-g5fc6cf4
 # ABSTRACT: a web application that provides access to Beanstalk statistics and tools
-
+# KEYWORDS: beanstalk jobs queue web application dashboard console plack psgi
+$Plack::App::BeanstalkConsole::VERSION = '0.008';
 use parent 'Plack::App::PHPCGIFile';
 
-use File::ShareDir;
-use Scalar::Util 'blessed';
-use namespace::autoclean;
+use File::ShareDir ();
+use Scalar::Util ();
 
 sub prepare_app
 {
     my $self = shift;
     if (not $self->{root})
     {
-        my $class = blessed $self;
+        my $class = Scalar::Util::blessed($self);
         (my $dist = $class) =~ s/::/-/g;
         $self->{root} = File::ShareDir::dist_dir($dist);
     }
@@ -53,15 +45,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Karen Etheridge Petr Sergey Trofimov irc beanstalkd
-
 =head1 NAME
 
 Plack::App::BeanstalkConsole - a web application that provides access to Beanstalk statistics and tools
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -81,6 +71,8 @@ command line.
 
 =head1 DESCRIPTION
 
+=for stopwords Petr Sergey Trofimov
+
 This is a simple L<Plack> wrapper for the excellent
 L<Beanstalk Console|https://github.com/ptrofimov/beanstalk_console>
 application written in PHP by Петр Трофимов (Petr Trofimov)
@@ -121,12 +113,16 @@ PHP, this is is normally installed as part of the main PHP installation.
 
 =head1 SUPPORT
 
+=for stopwords irc
+
 Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Plack-App-BeanstalkConsole>
 (or L<bug-Plack-App-BeanstalkConsole@rt.cpan.org|mailto:bug-Plack-App-BeanstalkConsole@rt.cpan.org>).
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
 =head1 SEE ALSO
 
+=for stopwords beanstalkd
+
 =over 4
 
 =item *
